You can read more about how to find older King’s Bench records in [Civil court cases: King’s/Queen’s Bench 1702-1998 research guide](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/court-of-kings-bench-plea-side-and-kings-queens-bench-division-cases-1702-1998/){target="\_blank"} or [Criminal court cases: King’s/Queen’s Bench 1675-1988](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/court-kings-bench-crown-side-1675-1875/){target="\_blank"}.
